<?php

namespace PortalPeople\caterpoint\models\products;

use Yii;

class Caterpoint extends \common\models\DynamicModel
{
    public static function segment_title(): string
    {
        return 'Caterpoint Attributes';
    }
    /**
     * Undocumented function
     *
     *    'colour' => [
     *        'rules' => [
     *            'string'
     *        ],
     *        'label' => Yii::t('app', "Colour",),
     *        'input' => 'default',
     *     ],
     * @return void
     */
    public static function localattributes(): array
    {
        return [
            'enabled' => [
                'rules' => [
                    ['boolean']
                ],
                'label' => Yii::t('app', "Enabled",),
                'input' => [
                    'input' => 'checkbox',
                    'options' => [
                        'value' => 1,
                        'label' => false,
                    ],
                ]
            ],
            'stock_code' => [
                'rules' => [
                    ['integer']
                ],
                'label' => Yii::t('app', "Stock Code",),
                'input' => 'default',
            ],
            'price' => [
                'rules' => [
                    ['number']
                ],
                'label' => Yii::t('app', "Price",),
                'input' => 'default',
            ],
        ];
    }


    public function dataLoad($modelData): void
    {
    }
}
