<?php

namespace PortalPeople\caterpoint\models\accounts;

use Yii;

class Caterpoint extends \common\models\DynamicModel
{
    public static function segment_title(): string
    {
        return 'Caterpoint Attributes';
    }

    public static function localattributes(): array
    {
        return [
            'caterpoint_code' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Caterpoint Code'),
                'input' => 'default',
            ],
        ];
    }

    public function dataLoad($modelData): void
    {
    }
}
